public inbox for devel@edk2.groups.io
 help / color / mirror / Atom feed
From: Gary Lin <glin@suse.com>
To: edk2-devel@lists.01.org
Cc: Feng Tian <feng.tian@intel.com>, Star Zeng <star.zeng@intel.com>
Subject: [PATCH 19/33] MdeModulePkg/Include: Fix typos in comments
Date: Wed, 19 Oct 2016 15:01:24 +0800	[thread overview]
Message-ID: <20161019070138.16424-20-glin@suse.com> (raw)
In-Reply-To: <20161019070138.16424-1-glin@suse.com>

- opints -> points
- sucessfully -> successfully
- suported -> supported
- hexidecimal -> hexadecimal
- TURE -> TRUE
- servity -> severity
- Moudle -> Module
- contiue -> continue
- infomation -> information
- malformated -> malformatted
- Pepresentation -> Representation
- opeque -> opaque
- assocated -> associated
- Libary -> Library
- descrption -> description
- paramter -> parameter
- chracter -> character

Cc: Feng Tian <feng.tian@intel.com>
Cc: Star Zeng <star.zeng@intel.com>
Contributed-under: TianoCore Contribution Agreement 1.0
Signed-off-by: Gary Lin <glin@suse.com>
---
 MdeModulePkg/Include/Library/CustomizedDisplayLib.h |  2 +-
 MdeModulePkg/Include/Library/DebugAgentLib.h        |  4 +--
 MdeModulePkg/Include/Library/HiiLib.h               | 16 +++++-----
 MdeModulePkg/Include/Library/NetLib.h               | 32 ++++++++++----------
 MdeModulePkg/Include/Ppi/AtaController.h            |  2 +-
 5 files changed, 28 insertions(+), 28 deletions(-)

diff --git a/MdeModulePkg/Include/Library/CustomizedDisplayLib.h b/MdeModulePkg/Include/Library/CustomizedDisplayLib.h
index 31e1091..1689e2c 100644
--- a/MdeModulePkg/Include/Library/CustomizedDisplayLib.h
+++ b/MdeModulePkg/Include/Library/CustomizedDisplayLib.h
@@ -202,7 +202,7 @@ PrintStringAtWithWidth (
   );
 
 /**
-  Prints a chracter to the default console, at
+  Prints a character to the default console, at
   the supplied cursor position, using L"%c" format.
 
   @param  Column     The cursor position to print the string at. When it is -1, use current Position.
diff --git a/MdeModulePkg/Include/Library/DebugAgentLib.h b/MdeModulePkg/Include/Library/DebugAgentLib.h
index 01b06a7..63d1c8f 100644
--- a/MdeModulePkg/Include/Library/DebugAgentLib.h
+++ b/MdeModulePkg/Include/Library/DebugAgentLib.h
@@ -39,7 +39,7 @@ typedef struct {
 /**
   Caller provided function to be invoked at the end of InitializeDebugAgent().
 
-  Refer to the descrption for InitializeDebugAgent() for more details.
+  Refer to the description for InitializeDebugAgent() for more details.
 
   @param[in] Context    The first input parameter of InitializeDebugAgent().
 
@@ -61,7 +61,7 @@ VOID
   function and pass it into InitializeDebugAgent(). InitializeDebugAgent() is
   responsible to invoke the passing-in function at the end of InitializeDebugAgent().
 
-  If the parameter Function is not NULL, Debug Agent Libary instance will invoke it by
+  If the parameter Function is not NULL, Debug Agent Library instance will invoke it by
   passing in the Context to be its parameter.
 
   If Function() is NULL, Debug Agent Library instance will return after setup debug
diff --git a/MdeModulePkg/Include/Library/HiiLib.h b/MdeModulePkg/Include/Library/HiiLib.h
index 4ad4cf1..3d87677 100644
--- a/MdeModulePkg/Include/Library/HiiLib.h
+++ b/MdeModulePkg/Include/Library/HiiLib.h
@@ -230,13 +230,13 @@ HiiGetHiiHandles (
   for freeing the allocated buffer using FreePool().
 
   @param Handle            The HII handle.
-  @param Buffer            On return, opints to a pointer which point to the buffer that contain the formset opcode.
+  @param Buffer            On return, points to a pointer which point to the buffer that contain the formset opcode.
   @param BufferSize        On return, points to the length of the buffer.
 
   @retval EFI_OUT_OF_RESOURCES   No enough memory resource is allocated.
   @retval EFI_NOT_FOUND          Can't find the package data for the input Handle.
   @retval EFI_INVALID_PARAMETER  The input parameters are not correct.
-  @retval EFI_SUCCESS            Get the formset opcode from the hii handle sucessfully.
+  @retval EFI_SUCCESS            Get the formset opcode from the hii handle successfully.
 
 **/
 EFI_STATUS
@@ -259,9 +259,9 @@ HiiGetFormSetFromHiiHandle(
   @param[in]  HiiHandle  A handle that was previously registered in the HII Database.
 
   @retval NULL   HiiHandle is not registered in the HII database
-  @retval NULL   There are not enough resources available to retrieve the suported 
+  @retval NULL   There are not enough resources available to retrieve the supported
                  languages.
-  @retval NULL   The list of suported languages could not be retrieved.
+  @retval NULL   The list of supported languages could not be retrieved.
   @retval Other  A pointer to the Null-terminated ASCII string of supported languages.
 
 **/
@@ -284,17 +284,17 @@ HiiGetSupportedLanguages (
 
   @param[in]  Guid          The pointer to an EFI_GUID that is the routing information
                             GUID.  Each of the 16 bytes in Guid is converted to 
-                            a 2 Unicode character hexidecimal string.  This is 
+                            a 2 Unicode character hexadecimal string.  This is
                             an optional parameter that may be NULL.
   @param[in]  Name          The pointer to a Null-terminated Unicode string that is 
                             the routing information NAME.  This is an optional 
                             parameter that may be NULL.  Each 16-bit Unicode 
                             character in Name is converted to a 4 character Unicode 
-                            hexidecimal string.                        
+                            hexadecimal string.
   @param[in]  DriverHandle  The driver handle that supports a Device Path Protocol
                             that is the routing information PATH.  Each byte of
                             the Device Path associated with DriverHandle is converted
-                            to a two (Unicode) character hexidecimal string.
+                            to a two (Unicode) character hexadecimal string.
 
   @retval NULL   DriverHandle does not support the Device Path Protocol.
   @retval NULL   DriverHandle does not support the Device Path Protocol.
@@ -322,7 +322,7 @@ HiiConstructConfigHdr (
                     entirety of the current HII database will be reset.
   @param DefaultId  Specifies the type of defaults to retrieve.
   
-  @retval TURE    The default value was set successfully.
+  @retval TRUE    The default value was set successfully.
   @retval FALSE   The default value was not found.
 **/
 BOOLEAN
diff --git a/MdeModulePkg/Include/Ppi/AtaController.h b/MdeModulePkg/Include/Ppi/AtaController.h
index aa4ae56..2333bef 100644
--- a/MdeModulePkg/Include/Ppi/AtaController.h
+++ b/MdeModulePkg/Include/Ppi/AtaController.h
@@ -106,7 +106,7 @@ typedef struct {
   @param[in] PeiServices   The pointer to the PEI Services Table.
   @param[in] This          The pointer to this instance of the PEI_ATA_CONTROLLER_PPI.
   @param[in] ChannelMask   The bitmask that identifies the IDE and SATA channels to 
-                           enable or disable. This paramter is optional. 
+                           enable or disable. This parameter is optional.
 
   @retval EFI_SUCCESS        The IDE or SATA channels were enabled or disabled successfully.
   @retval EFI_DEVICE_ERROR   The IDE or SATA channels could not be enabled or disabled.
diff --git a/MdeModulePkg/Include/Library/NetLib.h b/MdeModulePkg/Include/Library/NetLib.h
index 87f393e..c5c0fc2 100644
--- a/MdeModulePkg/Include/Library/NetLib.h
+++ b/MdeModulePkg/Include/Library/NetLib.h
@@ -252,7 +252,7 @@ typedef struct {
 
 //
 // The debug level definition. This value is also used as the
 // syslog's servity level. Don't change it.
 //
 #define NETDEBUG_LEVEL_TRACE   5
 #define NETDEBUG_LEVEL_WARNING 4
@@ -335,8 +335,8 @@ NetDebugASPrint (
   This function will locate a instance of SNP then send the message through it.
   Because it isn't open the SNP BY_DRIVER, apply caution when using it.
 
-  @param Level    The servity level of the message.
-  @param Module   The Moudle that generates the log.
+  @param Level    The severity level of the message.
+  @param Module   The Module that generates the log.
   @param File     The file that contains the log.
   @param Line     The exact line that contains the log.
   @param Message  The user message to log.
@@ -750,7 +750,7 @@ NetDestroyLinkList (
   @param[in]  ChildHandleBuffer  An array of child handles to be freed. May be NULL
                                  if NumberOfChildren is 0.
 
-  @retval TURE                   Found the input Handle in ChildHandleBuffer.
+  @retval TRUE                   Found the input Handle in ChildHandleBuffer.
   @retval FALSE                  Can't find the input Handle in ChildHandleBuffer.
 
 **/
@@ -1008,7 +1008,7 @@ EFI_STATUS
 /**
   Iterate through the netmap and call CallBack for each item.
 
-  It will contiue the traverse if CallBack returns EFI_SUCCESS, otherwise, break
+  It will continue the traverse if CallBack returns EFI_SUCCESS, otherwise, break
   from the loop. It returns the CallBack's last return value. This function is
   delete safe for the current item.
 
@@ -1308,7 +1308,7 @@ NetLibCreateIPv6DPathNode (
   needs to find its own private data that is related the IP's
   service binding instance that is installed on the UNDI/SNP handle.
   The controller is then either an MNP or an ARP child handle. Note that
-  IP opens these handles using BY_DRIVER. Use that infomation to get the
+  IP opens these handles using BY_DRIVER. Use that information to get the
   UNDI/SNP handle.
 
   @param[in]  Controller            The protocol handle to check.
@@ -1349,7 +1349,7 @@ NetLibDefaultUnload (
   @param[out]     Ip4Address     The pointer to the converted IPv4 address.
 
   @retval EFI_SUCCESS            Converted to an IPv4 address successfully.
-  @retval EFI_INVALID_PARAMETER  The string is malformated, or Ip4Address is NULL.
+  @retval EFI_INVALID_PARAMETER  The string is malformatted, or Ip4Address is NULL.
 
 **/
 EFI_STATUS
@@ -1361,13 +1361,13 @@ NetLibAsciiStrToIp4 (
 
 /**
   Convert one Null-terminated ASCII string to EFI_IPv6_ADDRESS. The format of the
-  string is defined in RFC 4291 - Text Pepresentation of Addresses.
+  string is defined in RFC 4291 - Text Representation of Addresses.
 
   @param[in]      String         The pointer to the Ascii string.
   @param[out]     Ip6Address     The pointer to the converted IPv6 address.
 
   @retval EFI_SUCCESS            Converted to an IPv6 address successfully.
-  @retval EFI_INVALID_PARAMETER  The string is malformated, or Ip6Address is NULL.
+  @retval EFI_INVALID_PARAMETER  The string is malformatted, or Ip6Address is NULL.
 
 **/
 EFI_STATUS
@@ -1384,7 +1384,7 @@ NetLibAsciiStrToIp6 (
   @param[out]     Ip4Address     The pointer to the converted IPv4 address.
 
   @retval EFI_SUCCESS            Converted to an IPv4 address successfully.
-  @retval EFI_INVALID_PARAMETER  The string is mal-formated or Ip4Address is NULL.
+  @retval EFI_INVALID_PARAMETER  The string is mal-formatted or Ip4Address is NULL.
   @retval EFI_OUT_OF_RESOURCES   Failed to perform the operation due to lack of resources.
 
 **/
@@ -1397,13 +1397,13 @@ NetLibStrToIp4 (
 
 /**
   Convert one Null-terminated Unicode string to EFI_IPv6_ADDRESS.  The format of
-  the string is defined in RFC 4291 - Text Pepresentation of Addresses.
+  the string is defined in RFC 4291 - Text Representation of Addresses.
 
   @param[in]      String         The pointer to the Ascii string.
   @param[out]     Ip6Address     The pointer to the converted IPv6 address.
 
   @retval EFI_SUCCESS            Converted to an IPv6 address successfully.
-  @retval EFI_INVALID_PARAMETER  The string is malformated or Ip6Address is NULL.
+  @retval EFI_INVALID_PARAMETER  The string is malformatted or Ip6Address is NULL.
   @retval EFI_OUT_OF_RESOURCES   Failed to perform the operation due to a lack of resources.
 
 **/
@@ -1416,7 +1416,7 @@ NetLibStrToIp6 (
 
 /**
   Convert one Null-terminated Unicode string to EFI_IPv6_ADDRESS and prefix length.
-  The format of the string is defined in RFC 4291 - Text Pepresentation of Addresses
+  The format of the string is defined in RFC 4291 - Text Representation of Addresses
   Prefixes: ipv6-address/prefix-length.
 
   @param[in]      String         The pointer to the Ascii string.
@@ -1424,7 +1424,7 @@ NetLibStrToIp6 (
   @param[out]     PrefixLength   The pointer to the converted prefix length.
 
   @retval EFI_SUCCESS            Converted to an  IPv6 address successfully.
-  @retval EFI_INVALID_PARAMETER  The string is malformated, or Ip6Address is NULL.
+  @retval EFI_INVALID_PARAMETER  The string is malformatted, or Ip6Address is NULL.
   @retval EFI_OUT_OF_RESOURCES   Failed to perform the operation due to a lack of resources.
 
 **/
@@ -1493,9 +1493,9 @@ typedef struct {
   UINT32              Signature;
   INTN                RefCnt;  // Reference count to share NET_VECTOR.
   NET_VECTOR_EXT_FREE Free;    // external function to free NET_VECTOR
-  VOID                *Arg;    // opeque argument to Free
+  VOID                *Arg;    // opaque argument to Free
   UINT32              Flag;    // Flags, NET_VECTOR_OWN_FIRST
-  UINT32              Len;     // Total length of the assocated BLOCKs
+  UINT32              Len;     // Total length of the associated BLOCKs
 
   UINT32              BlockNum;
   NET_BLOCK           Block[1];
@@ -252,7 +252,7 @@ typedef struct {
 //
 // The debug level definition. This value is also used as the
-// syslog's servity level. Don't change it.
+// syslog's severity level. Don't change it.
 //
 #define NETDEBUG_LEVEL_TRACE   5
-- 
2.10.1



  parent reply	other threads:[~2016-10-19  7:03 UTC|newest]

Thread overview: 79+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2016-10-19  7:01 [PATCH 00/33] Fix typos in comments and variables Gary Lin
2016-10-19  7:01 ` [PATCH 01/33] ArmPkg: Fix typos in comments Gary Lin
2016-10-19 15:09   ` Ard Biesheuvel
2016-10-19 15:15     ` Laszlo Ersek
2016-10-19 15:33       ` Leif Lindholm
2016-10-19  7:01 ` [PATCH 02/33] BaseTools: Fix typos in comments and variables Gary Lin
2016-10-19  7:30   ` Gao, Liming
2016-10-19  7:36   ` Zhu, Yonghong
2016-10-19  7:01 ` [PATCH 03/33] CorebootPayloadPkg: Fix typos in comments Gary Lin
2016-10-26 18:50   ` Ma, Maurice
2016-10-19  7:01 ` [PATCH 04/33] CorebootModulePkg: " Gary Lin
2016-10-26 18:41   ` Ma, Maurice
2016-10-19  7:01 ` [PATCH 05/33] CryptoPkg: " Gary Lin
2016-10-26  3:00   ` Long, Qin
2016-10-19  7:01 ` [PATCH 06/33] DuetPkg: " Gary Lin
2016-10-19  7:46   ` Ni, Ruiyu
2016-10-19  7:01 ` [PATCH 07/33] EdkCompatibilityPkg: " Gary Lin
2016-10-19  8:19   ` Gao, Liming
2016-10-19  7:01 ` [PATCH 08/33] EmulatorPkg: Fix typos in comments and variables Gary Lin
2016-10-19 20:37   ` Jordan Justen
2016-10-20  8:16     ` Laszlo Ersek
2016-10-19  7:01 ` [PATCH 09/33] EmbeddedPkg: Fix typos in comments Gary Lin
2016-10-19 15:09   ` Ard Biesheuvel
2016-10-19  7:01 ` [PATCH 10/33] IntelFrameworkModulePkg: " Gary Lin
2016-10-20  1:08   ` Fan, Jeff
2016-10-19  7:01 ` [PATCH 11/33] IntelFrameworkPkg: " Gary Lin
2016-10-20  1:08   ` Fan, Jeff
2016-10-19  7:01 ` [PATCH 12/33] IntelFspPkg: " Gary Lin
2016-10-19  7:06   ` Yao, Jiewen
2016-10-19  7:01 ` [PATCH 13/33] IntelFspWrapperPkg: " Gary Lin
2016-10-19  7:08   ` Yao, Jiewen
2016-10-19  7:01 ` [PATCH 14/33] IntelFsp2Pkg: " Gary Lin
2016-10-19  7:06   ` Yao, Jiewen
2016-10-19  7:12   ` Mudusuru, Giri P
2016-10-19  7:01 ` [PATCH 15/33] IntelFsp2WrapperPkg: Fix a typo in the comment Gary Lin
2016-10-19  7:07   ` Yao, Jiewen
2016-10-19  7:11   ` Mudusuru, Giri P
2016-10-19  7:01 ` [PATCH 16/33] MdeModulePkg: BootManagerMenuApp: Fix typos in comments Gary Lin
2016-10-19  8:20   ` Tian, Feng
2016-10-19  7:01 ` [PATCH 17/33] MdeModulePkg/Bus: " Gary Lin
2016-10-19  7:01 ` [PATCH 18/33] MdeModulePkg/Core: " Gary Lin
2016-10-19  8:20   ` Tian, Feng
2016-10-19  7:01 ` Gary Lin [this message]
2016-10-19  7:01 ` [PATCH 20/33] MdeModulePkg/Library: Fix typos in comments and variables Gary Lin
2016-10-19  7:01 ` [PATCH 21/33] MdeModulePkg/Universal: Fix typos in comments Gary Lin
2016-10-19  7:01 ` [PATCH 22/33] MdePkg: " Gary Lin
2016-10-19  8:21   ` Gao, Liming
2016-10-19  7:01 ` [PATCH 23/33] NetworkPkg: " Gary Lin
2016-10-19  7:21   ` Fu, Siyuan
2016-10-26  0:53   ` Fu, Siyuan
2016-10-19  7:01 ` [PATCH 24/33] Nt32Pkg: Fix typos in comments and variables Gary Lin
2016-10-19  7:50   ` Ni, Ruiyu
2016-10-19  7:01 ` [PATCH 25/33] OptionRomPkg: Fix typos in comments Gary Lin
2016-10-19  7:51   ` Ni, Ruiyu
2016-10-19  7:01 ` [PATCH 26/33] OvmfPkg: " Gary Lin
2016-10-19  7:01 ` [PATCH 27/33] QuarkPlatformPkg: " Gary Lin
2016-10-25 20:53   ` Kinney, Michael D
2016-10-19  7:01 ` [PATCH 28/33] QuarkSocPkg: " Gary Lin
2016-10-25 21:00   ` Kinney, Michael D
2016-10-19  7:01 ` [PATCH 29/33] SecurityPkg: " Gary Lin
2016-10-27  1:29   ` Zhang, Chao B
2016-11-14  3:12   ` Zhang, Chao B
2016-11-14  4:03     ` Gary Lin
2016-11-14  6:24       ` Gao, Liming
2016-11-14  8:30         ` Gary Lin
2016-10-19  7:01 ` [PATCH 30/33] ShellPkg: Fix typos in comments and variables Gary Lin
2016-10-19  7:51   ` Ni, Ruiyu
2016-10-19 20:29     ` Carsey, Jaben
2016-10-20  1:55       ` Gary Lin
2016-10-19  7:01 ` [PATCH 31/33] SourceLevelDebugPkg: Fix typos in comments Gary Lin
2016-10-19  7:46   ` Wu, Hao A
2016-10-19  7:01 ` [PATCH 32/33] UefiCpuPkg: " Gary Lin
2016-10-20  1:58   ` Fan, Jeff
2016-10-20  2:08     ` Gary Lin
2016-10-20  2:45       ` Fan, Jeff
2016-10-19  7:01 ` [PATCH 33/33] Vlv2TbltDevicePkg: " Gary Lin
2016-10-24  1:33   ` Wei, David
2016-10-19  7:28 ` [PATCH 00/33] Fix typos in comments and variables Zeng, Star
2016-10-19 14:50 ` Leif Lindholm

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-list from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20161019070138.16424-20-glin@suse.com \
    --to=devel@edk2.groups.io \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox